{% for entry in entries %}
{% include 'components/pool_entry_row.html' %}
{% endfor %}

{% if has_more %}
<tr id="pool-load-more-{{ page }}"
    hx-get="{{ url_for('pool.get_entries', page=page, source=source_language, target=target_language) }}"
    hx-trigger="revealed"
    hx-target="this"
    hx-swap="outerHTML">
    <td colspan="7" class="loading-row">Loading more...</td>
</tr>
{% endif %}
