<tr id="entry-{{ entry.id }}">
    <td>
        <input type="checkbox" name="entry_ids" value="{{ entry.id }}" data-status="{{ entry.validation_status }}" style="cursor: pointer;">
    </td>
    <td>
        <span id="status-{{ entry.id }}">
            {% include 'components/validation_badge.html' %}
        </span>
    </td>
    <td>{{ entry.current_word }}</td>
    <td>{{ entry.current_translation }}</td>
    <td>
        <div id="example-{{ entry.id }}">
            {{ entry.current_example if entry.current_example else '—' }}
            {% if entry.example_license and entry.example_author %}
            <br><small style="color: #6b7280; font-size: 0.75rem;">
            {% if entry.example_source == "leipzig" %}
                Source: Leipzig Corpora Collection ({{ entry.example_license }})
            {% else %}
                Source: <a href="https://tatoeba.org/en/sentences/show/{{ entry.tatoeba_sentence_id }}" target="_blank" rel="noopener" style="color: #6b7280;">Tatoeba</a> ({{ entry.example_license }}) by {{ entry.example_author }}
            {% endif %}
            </small>
            {% endif %}
        </div>
    </td>
    <td>
        <small style="color: #6b7280;">{{ entry.upload.filename }}</small>
    </td>
    <td class="actions">
        <button hx-get="{{ url_for('edit.edit_form', entry_id=entry.id) }}"
                hx-target="#entry-{{ entry.id }}"
                hx-swap="outerHTML"
                class="btn btn-sm">
            Edit
        </button>
        {% if entry.needs_example %}
        <button hx-post="{{ url_for('tatoeba.fetch_example', entry_id=entry.id) }}"
                hx-target="#example-{{ entry.id }}"
                hx-swap="innerHTML"
                hx-disabled-elt="closest tr"
                hx-indicator="#loading-{{ entry.id }}"
                class="btn btn-sm btn-warning">
            Fetch Example
        </button>
        <span id="loading-{{ entry.id }}" class="htmx-indicator">⏳</span>
        {% endif %}
    </td>
</tr>
