{% for entry in entries %}
{% include 'components/entry_row.html' %}
{% endfor %}

{% if has_more %}
<tr id="load-more-{{ upload_id }}-{{ page }}"
    hx-get="{{ url_for('preview.get_entries', upload_id=upload_id, page=page) }}"
    hx-trigger="revealed"
    hx-target="this"
    hx-swap="outerHTML">
    <td colspan="5" class="loading-row">Loading more...</td>
</tr>
{% endif %}
