<!-- Update validation stats using Out-of-Band swap -->
<div id="validation-stats" hx-swap-oob="true" class="validation-stats">
    <h3>Validation Status</h3>
    <div class="stats-grid">
        <div class="stat-card stat-valid">
            <div class="stat-value">{{ stats.valid }}</div>
            <div class="stat-label">Valid</div>
        </div>
        <div class="stat-card stat-warning">
            <div class="stat-value">{{ stats.invalid_no_example }}</div>
            <div class="stat-label">No Example</div>
        </div>
        <div class="stat-card stat-error">
            <div class="stat-value">{{ stats.invalid_word_missing }}</div>
            <div class="stat-label">Word Missing</div>
        </div>
    </div>
    <button hx-post="{{ url_for('validate.validate_upload', upload_id=upload_id) }}"
            hx-target="#validation-stats"
            class="btn btn-sm">
        Re-validate All
    </button>
</div>

<!-- Update each entry's validation badge using Out-of-Band swaps -->
{% for entry in entries %}
<span id="status-{{ entry.id }}" hx-swap-oob="true">
    {% include 'components/validation_badge.html' %}
</span>
{% endfor %}
