{% extends "base.html" %}

{% block title %}Words to Readlang - Thanks{% endblock %}

{% block content %}
<div class="info" style="max-width: 700px; margin: 2rem auto;">
    <h2 style="margin-top: 0; margin-bottom: 1.5rem;">Thanks</h2>

    <p style="color: #6b7280; margin-bottom: 2rem;">
        This tool would make no sense or be impossible without the following. Thank you!
    </p>

    <div style="display: flex; flex-direction: column; gap: 2rem;">

        <div>
            <h3 style="margin-top: 0;">
                <a href="https://readlang.com" target="_blank" rel="noopener" style="color: #509aca; text-decoration: none;">Readlang</a>
            </h3>
            <p>
                Readlang is a wonderful language learning tool that lets you read real texts in your
                target language. You can look up words instantly, get explanations, highlight multiple words to get an in-context translation, it's really nice and Steve who builds it is also nice.
                But you're probably already using it, otherwise, why would you be here?
            </p>
            <p>
                This tool exists just to get words <em>into</em> Readlang
                more easily from other platforms (or from your own CSVs).
            </p>
        </div>

        <div>
            <h3 style="margin-top: 0;">
                <a href="https://tatoeba.org" target="_blank" rel="noopener" style="color: #509aca; text-decoration: none;">Tatoeba</a>
            </h3>
            <p>
                Tatoeba is a community-driven collection of sentences and translations in hundreds
                of languages, freely licensed. Thousands of contributors have spent enormous
                effort writing and translating natural example sentences.
            </p>
            <p>
                When Words to Readlang fetches an
                example sentence for a word, Tatoeba is one of the catalogs it queries.
                Tatoeba sentences are used under their respective
                <a href="https://tatoeba.org/en/terms_of_use" target="_blank" rel="noopener" style="color: #509aca;">Creative Commons licenses</a>.
            </p>
        </div>

        <div>
            <h3 style="margin-top: 0;">
                <a href="https://wortschatz.uni-leipzig.de" target="_blank" rel="noopener" style="color: #509aca; text-decoration: none;">Leipzig Corpora Collection</a>
            </h3>
            <p>
                The Leipzig Corpora Collection, maintained by the Natural Language Processing Group
                at Leipzig University, provides large text corpora for dozens of languages compiled
                from news sources and the web. Their public
                <a href="https://api.wortschatz-leipzig.de/ws/swagger-ui/index.html" target="_blank" rel="noopener" style="color: #509aca;">Wortschatz API</a>
                makes it possible to look up real example sentences for words across many languages. Sentences are provided under a
                <a href="https://creativecommons.org/licenses/by/4.0/" target="_blank" rel="noopener" style="color: #509aca;">CC BY</a> license.
            </p>
        </div>

    </div>
</div>
{% endblock %}
