<span class="example-text">{{ example }}</span>
{% if license and author %}
<br><small style="color: #6b7280; font-size: 0.75rem;">
{% if example_source == "leipzig" %}
    Source: Leipzig Corpora Collection ({{ license }})
{% else %}
    Source: <a href="https://tatoeba.org/en/sentences/show/{{ sentence_id }}" target="_blank" rel="noopener" style="color: #6b7280;">Tatoeba</a> ({{ license }}) by {{ author }}
{% endif %}
</small>
{% endif %}
