{% if entry.validation_status == 'valid' %}
<span class="badge badge-success" title="Example contains word">✓</span>
{% elif entry.validation_status == 'invalid_no_example' %}
<span class="badge badge-warning" title="No example sentence">⚠</span>
{% elif entry.validation_status == 'invalid_word_missing' %}
<span class="badge badge-error" title="Word not found in example">✗</span>
{% endif %}
